<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Ρυθμίσεις του επόπτη συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Ενεργοποίηση του επόπτη του συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Προειδοποίηση:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Το επίπεδο είναι χαμηλό στο:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Χρήση των εικονιδίων από το θέμα:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Φόρτιση</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Αποφόρτιση</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Όταν η ενέργεια είναι χαμηλά τότε:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Εμφάνιση του εικονιδίου:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>Ενσωματωμένο</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Επίπεδο: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Ενεργοποίηση του επόπτη α&amp;δράνειας</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Όταν είναι αδρανής:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Χρόνος αδράνειας:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> λεπτά</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> δευτερόλεπτα</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Ενεργοποίηση του επόπτη &amp;καλύμματος</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Ενέργεια κατά το κλείσιμο του καλύμματος</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>Σε συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Νάρκη</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>Σε τροφοδοτικό AC</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>Όταν χρησιμοποιείται εξωτερική ο&amp;θόνη</translation>
    </message>
    <message>
        <source>On Ac</source>
        <translation type="vanished">Σε τροφοδοτικό AC</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>LXQt Powermanagement Configuration</source>
        <translation type="vanished">Διαμόρφωση της διαχείρισης ενέργειας του LXQt</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Ρυθμίσεις της διαχείρισης ενέργειας</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Συσσωρευτής</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Κάλυμμα φορητού</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Αδρανής</translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">Αδράνεια</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Κλείδωμα οθόνης</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Νάρκη</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="40"/>
        <source>Turn Off monitor(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
